@@ -104,7 +104,11 @@ class Revealer(presalytics.story.components.Renderer):
             client.exchange_token(website_token, audience='story-ui')
             base.attrib['data-jwt'] = client.token_util.token["access_token"]
             base.attrib['data-jwt-refresh'] = client.token_util.token["refresh_token"]
-            base.attrib['data-story-target'] = client.story.api_client.configuration.host
+            if presalytics.CONFIG.get("BROWSER_API_HOST", None):
+                story_target = presalytics.CONFIG["BROWSER_API_HOST"] + "/story"
+            else:
+                story_target = client.story.api_client.configuration.host
+            base.attrib['data-story-target'] = story_target
         except Exception as ex:
             logger.exception(ex, "Could not obtain access token from revealer component.")
 
